@@ -1043,10 +1043,8 @@ int Kwave::TopWidget::loadFile(const QUrl &url)
     // NOTE: the context may have changed, now we may have a different
     //       signal manager
     signal_manager = context->signalManager();
-    int res = -ENOMEM;
-    if (signal_manager && !(res = signal_manager->loadFile(url))) {
-	// succeeded
-    } else {
+    int res = (signal_manager) ? signal_manager->loadFile(url) : -ENOMEM;
+    if (res != 0) {
 	qWarning("TopWidget::loadFile() failed: result=%d", res);
 	QString reason;
 	switch (res) {
@@ -1200,7 +1198,7 @@ void Kwave::TopWidget::selectionChanged(sample_index_t offset,
 	// show offset and length
 	// Selected: 2000...3000 (1000 samples)
 	// Selected: 02:00...05:00 (3 min)
-	sample_index_t last = offset + ((length) ? length-1 : 0);
+	sample_index_t last = offset + length - 1;
 
 	QString txt = _(" ");
 	if (sample_mode) {
