@@ -28,13 +28,13 @@
 Kwave::SelectionTracker::SelectionTracker(Kwave::SignalManager *signal,
                                           sample_index_t offset,
                                           sample_index_t length,
-					  const QVector<unsigned int> *tracks)
+                                          const QVector<unsigned int> *tracks)
     :m_signal(signal),
      m_offset(offset),
      m_length((length || !signal) ? length : signal->length()),
      m_tracks(),
      m_selection_only((length != 0)),
-     m_lock(QMutex::Recursive)
+     m_lock()
 {
     Q_ASSERT(signal);
     if (!signal) return;
