@@ -61,7 +61,8 @@ void Kwave::VorbisDecoder::parseTag(Kwave::FileInfo &info, const char *tag,
     if (count < 1) return;
     QString value;
     for (int i = 0; i < count; ++i) {
-	char *text = vorbis_comment_query(&m_vc, const_cast<char *>(tag), i);
+	const char *text = vorbis_comment_query(&m_vc,
+	    const_cast<char *>(tag), i);
 	if (i) value += _("; ");
 	value += QString::fromUtf8(text);
     }
@@ -217,7 +218,7 @@ int Kwave::VorbisDecoder::open(QWidget *widget, Kwave::FileInfo &info)
 	if ((br < 0) && (m_vi.bitrate_lower   > 0)) br = m_vi.bitrate_lower;
 	qint64 file_size       = m_source->size();
 	qreal rate             = static_cast<qreal>(m_vi.rate);
-	qreal seconds          = (br > 0) ?
+	qreal seconds          = (br >= 8) ?
 	    static_cast<qreal>(file_size / (br / 8)) : DEFAULT_BITRATE;
 	sample_index_t samples = static_cast<sample_index_t>(seconds * rate);
 
