@@ -32,6 +32,7 @@
 #include <QRegExp>
 #include <QTextStream>
 
+#include <KLazyLocalizedString>
 #include <KLocalizedString> // for the i18n macro
 #include <KZip>
 
@@ -99,7 +100,7 @@ int Kwave::K3BExportPlugin::interpreteParameters(QStringList &params)
 	return -EINVAL;
 
     // the selected URL
-    m_url = QUrl::fromUserInput(Kwave::Parser::unescape(params[0]));
+    m_url = Kwave::URLfromUserInput(Kwave::Parser::unescape(params[0]));
     if (!m_url.isValid()) return -EINVAL;
 
     // label pattern
@@ -272,10 +273,10 @@ void Kwave::K3BExportPlugin::load(QStringList &params)
 {
     Q_UNUSED(params)
 
-    QString menu_path = _("File/Save/%1").arg(_(I18N_NOOP2(
+    QString menu_path = _("File/Save/%1").arg(_(kli18nc(
 	"menu: /File/Save/Export to K3b Project...",
-	                 "Export to K3b Project..."
-    )));
+	                 "Export to K3b Project...").untranslatedText()
+    ));
     emitCommand(_("menu(plugin:setup(export_k3b),%1%2)").arg(
 	menu_path).arg(_("/#group(@SIGNAL)")));
     emitCommand(_("menu(plugin:setup(export_k3b),%1%2)").arg(
@@ -308,7 +309,7 @@ QStringList *Kwave::K3BExportPlugin::setup(QStringList &params)
 		"K3b project file (*.k3b)"
 	    ),
 	    parentWidget(),
-	    QUrl::fromUserInput(signalName()),
+	    Kwave::URLfromUserInput(signalName()),
 	    _("*.k3b"),
 	    m_pattern,
 	    m_selection_only,
