@@ -16,12 +16,16 @@
  ***************************************************************************/
 
 #include "config.h"
+
 #include <errno.h>
 #include <math.h>
+#include <new>
+
+#include <QDialog>
+#include <QPointer>
+#include <QString>
 
 #include <KLocalizedString>
-#include <QDialog>
-#include <QString>
 
 #include "libkwave/Plugin.h"
 #include "libkwave/PluginManager.h"
@@ -57,15 +61,17 @@ QStringList *Kwave::GotoPluginBase::setup(QStringList &previous_params)
     // get the name of the help section
     QString help_section = _("plugin_sect_") + command();
 
-    Kwave::GotoDialog *dialog = new Kwave::GotoDialog(parentWidget(),
-        m_mode, m_position, rate, length, help_section);
+    QPointer<Kwave::GotoDialog> dialog = new(std::nothrow)
+	Kwave::GotoDialog(parentWidget(),
+	    m_mode, m_position, rate, length, help_section
+	);
     Q_ASSERT(dialog);
     if (!dialog) return Q_NULLPTR;
 
     // set the title of the dialog, depending on the derived class
     dialog->setWindowTitle(title());
 
-    QStringList *list = new QStringList();
+    QStringList *list = new(std::nothrow) QStringList();
     Q_ASSERT(list);
     if (list && dialog->exec()) {
 	// user has pressed "OK"
@@ -83,7 +89,7 @@ QStringList *Kwave::GotoPluginBase::setup(QStringList &previous_params)
         list = Q_NULLPTR;
     }
 
-    if (dialog) delete dialog;
+    delete dialog;
     return list;
 }
 
