@@ -399,7 +399,6 @@ QString Kwave::PlayBackOSS::fileFilter()
 {
     QString filter;
 
-    if (filter.length()) filter += _("\n");
     filter += _("dsp*|") + i18n("OSS playback device (dsp*)");
 
     if (filter.length()) filter += _("\n");
@@ -553,12 +552,12 @@ QList<unsigned int> Kwave::PlayBackOSS::supportedBits(const QString &device)
     // mask out all modes that do not match the current compression
     const int compression = Kwave::Compression::NONE;
     for (unsigned int bit=0; bit < (sizeof(mask) << 3); bit++) {
-	if (!(mask & (1 << bit))) continue;
+	if (!(mask & (1U << bit))) continue;
 
 	// format is supported, split into compression, bits, sample format
 	int c, b;
 	Kwave::SampleFormat::Format s;
-	format2mode(1 << bit, c, b, s);
+	format2mode(1U << bit, c, b, s);
 	if (b < 0) continue; // unknown -> skip
 
 	// take the mode if compression matches and it is not already known
