@@ -35,10 +35,10 @@ namespace Kwave
 	}
 
 	/** Destructor */
-	virtual ~RecordTypesMap() {}
+        virtual ~RecordTypesMap() Q_DECL_OVERRIDE {}
 
 	/** fill function for the map */
-	void fill() Q_DECL_OVERRIDE;
+        virtual void fill() Q_DECL_OVERRIDE;
     };
 }
 
